<?php

/**
 *	This file holds the configuration constants and variables
 *	for the add course tool.
 *
 *	@package chamilo.configuration
 */

$firstExpirationDelay = 31536000; // <- 86400*365    // 60*60*24 = 1 jour = 86400
$prefixAntiNumber = 'z';
$DEBUG = false;
